Citing Pooch
============

This is research software **made by scientists**. Citations help us justify the
effort that goes into building and maintaining this project.

If you used Pooch in your research, please consider citing our paper:

    Uieda, L., Soler, S.R., Rampin, R., van Kemenade, H., Turk, M., Shapero,
    D., Banihirwe, A., and Leeman, J. (2020). Pooch: A friend to fetch your
    data files. Journal of Open Source Software, 5(45), 1943.
    doi:10.21105/joss.01943

This is an open-access publication. The paper and the associated software
review can be freely accessed at: https://doi.org/10.21105/joss.01943

If you need a Bibtex entry for the paper, grab it here:
https://www.doi2bib.org/bib/10.21105/joss.01943
